@@ -9,8 +9,8 @@ import os
 from PIL import Image
 
 from jupyter_dash import JupyterDash
-from dash import dcc
-from dash import html
+import dash_core_components as dcc
+import dash_html_components as html
 from dash.dependencies import Input, Output, State
 from dash import callback_context
 
